package com.bsz.school_send_back_end.controller;


import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.bsz.school_send_back_end.common.BaseResponse;
import com.bsz.school_send_back_end.common.ErrorCode;
import com.bsz.school_send_back_end.common.ResultUtils;
import com.bsz.school_send_back_end.exception.BusinessException;
import com.bsz.school_send_back_end.exception.ThrowUtils;
import com.bsz.school_send_back_end.model.domain.User;
import com.bsz.school_send_back_end.model.domain.UserRating;
import com.bsz.school_send_back_end.model.dto.CommonRequest;
import com.bsz.school_send_back_end.model.dto.userRating.UserRatingAddRequest;
import com.bsz.school_send_back_end.service.UserRatingService;
import com.bsz.school_send_back_end.service.UserService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.BeanUtils;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.util.List;

@RestController
@Slf4j
@RequestMapping("/level")
public class UserRatingController {

    @Resource
    private UserRatingService userRatingService;

    @Resource
    private UserService userService;

    /**
     * 添加用户评分
     * @param userRatingAddRequest 用户评分请求
     * @param request 当期那登录用户
     * @return 是否添加成功
     */
    @PostMapping("/add")
    public BaseResponse<Boolean> addRating (@RequestBody UserRatingAddRequest userRatingAddRequest, HttpServletRequest request) {
        if (userRatingAddRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }

        UserRating userRating = new UserRating();
        BeanUtils.copyProperties(userRatingAddRequest, userRating);
        userRatingService.validUserRating(userRating, request);
        boolean save = userRatingService.save(userRating);
        ThrowUtils.throwIf(!save, ErrorCode.SYSTEM_ERROR, "添加失败");
        return ResultUtils.success(true);
    }

    /**
     * 删除用户评分
     * @param commonRequest 用户评分id
     * @return 是否删除成功
     */
    @PostMapping("/delete")
    public BaseResponse<Boolean> deleteUserRating (@RequestBody CommonRequest commonRequest) {
        if (commonRequest == null) {
            throw new BusinessException(ErrorCode.PARAMS_ERROR);
        }
        boolean remove = userRatingService.removeById(commonRequest.getId());
        ThrowUtils.throwIf(!remove, ErrorCode.SYSTEM_ERROR, "删除失败");

        return ResultUtils.success(true);
    }

    /**
     * 展示当前用户评分
     * @param request 当前用户
     * @return 评分列表
     */
    @PostMapping("/list")
    public BaseResponse<List<UserRating>> listUserRating (HttpServletRequest request) {
        User loginUser = userService.getLoginUser(request);
        Long userId = loginUser.getId();
        List<UserRating> list = userRatingService.list(Wrappers.<UserRating>lambdaQuery().eq(UserRating::getUserId, userId));
        return ResultUtils.success(list);
    }
}
